from zope import interface

class IJabberHelpdeskKSSCommands(interface.Interface):
	"""Livechat KSS commands
	"""

	def jh_resetScrollbar(selector):
		"""
		"""
	def jh_resetInput(selector):
		"""
		"""